define({ "api": [
  {
    "type": "POST",
    "url": "/api/v1/identchecks.json",
    "title": "Create new identcheck",
    "name": "create_identcheck",
    "group": "IDENTPLUS",
    "version": "1.0.0",
    "header": {
      "fields": {
        "Header": [
          {
            "group": "Header",
            "type": "String",
            "optional": false,
            "field": "Accept",
            "description": "<p>application/json</p>"
          },
          {
            "group": "Header",
            "type": "String",
            "allowedValues": [
              "\"Bearer :token\""
            ],
            "optional": false,
            "field": "Authorization",
            "description": "<p>Replace <code>:token</code> with the supplied Auth Token.</p>"
          }
        ]
      },
      "examples": [
        {
          "title": "Request: Header example",
          "content": "{\n  Accept: \"application/json\",\n  Authorization: \"Bearer XXXXXXXX-XXXX-XXXX-XXXX-XXXXXXXXXXXX\"\n}",
          "type": "json"
        }
      ]
    },
    "description": "<p>Create a new identcheck instance.<br><br></p>",
    "parameter": {
      "fields": {
        "Parameter": [
          {
            "group": "Parameter",
            "type": "String",
            "optional": false,
            "field": "ident_code",
            "description": "<p>Identification code.<br> To be passed to the purpose element of the SCT payment order. <p>Constraints:<br> * Pattern: <code> /\\A(?=.*[0-9])(?=.*[a-z])([a-z0-9]+)\\z/ </code> <br> * Min length: 6<br> * Max length: 15</p></p>"
          },
          {
            "group": "Parameter",
            "type": "String",
            "allowedValues": [
              "\"LESSOR\"",
              "\"LESSEE\"",
              "\"CARETAKER\""
            ],
            "optional": false,
            "field": "partner_type",
            "description": "<p>Type of the partner.<br></p>"
          },
          {
            "group": "Parameter",
            "type": "String",
            "optional": false,
            "field": "partner_iban",
            "description": "<p>Valid IBAN of the partner. <p>Constraints:<br> * Must start with: <code>&quot;DE&quot;</code><br> * Max length: 22</p></p>"
          },
          {
            "group": "Parameter",
            "type": "String",
            "allowedValues": [
              "\"M\"",
              "\"W\"",
              "\"U\""
            ],
            "optional": false,
            "field": "partner_gender",
            "description": "<p>Gender of the partner.<br> Codes are: &quot;M&quot; - male, &quot;W&quot; - female, &quot;U&quot; - unknown</p>"
          },
          {
            "group": "Parameter",
            "type": "String",
            "optional": false,
            "field": "partner_firstname",
            "description": "<p>First name of the partner. <p>Constraints:<br> * Pattern: <code> /\\A[a-zA-ZäÄöÖüÜß]+[a-zA-ZäÄöÖüÜß .-]+\\z/ </code> <br> * Min length: 2<br> * Max length: 44</p></p>"
          },
          {
            "group": "Parameter",
            "type": "String",
            "optional": false,
            "field": "partner_lastname",
            "description": "<p>Last name of the partner.<br> <p>Constraints:<br> * Pattern: <code> /\\A(?=.*[a-zA-ZäÄöÖüÜß]+)[a-zA-ZäÄöÖüÜß .-]+\\z/ </code> <br> * Max length: 46</p> <p>The payment order requires a name for the payee.<br> This field is assembled from the fields <code>partner_lastname</code> and <code>partner_firstname</code>.</p> <p>However, the payee's name must match a stricter pattern than it applies to the source fields.<br> If the validation for the payee's name fails the application tries to adapt certain charaters, e.g. &quot;ü&quot; to &quot;ue&quot;.<br> If the validation still fails a defined fallback name is used instead.</p></p>"
          },
          {
            "group": "Parameter",
            "type": "String",
            "optional": false,
            "field": "partner_birthdate",
            "description": "<p>Birth date of the partner.<br> <p>Required format: <code>&quot;yyyy-mm-dd&quot;</code></p></p>"
          },
          {
            "group": "Parameter",
            "type": "String",
            "optional": false,
            "field": "partner_street",
            "description": "<p>Street name of the partner's address without house number. <p>Constraints:<br> * Pattern: <code> /\\A[0-9a-zA-ZäÄöÖüÜß .-]+\\z/ </code> <br> * Max length for <code>partner_street_and_partner_housenumber</code><br>   inclusive a concatenating blank in total: 46</p></p>"
          },
          {
            "group": "Parameter",
            "type": "String",
            "optional": false,
            "field": "partner_housenumber",
            "description": "<p>House number of the partner's address. <p>Constraints:<br> * Pattern: <code> /\\A[0-9a-zA-Z/ .-]+\\z/ </code><br> * Max length for <code>partner_street_and_partner_housenumber</code><br>   inclusive a concatenating blank in total: 46</p></p>"
          },
          {
            "group": "Parameter",
            "type": "String",
            "optional": false,
            "field": "partner_postcode",
            "description": "<p>Post code of the partner's address. <p>Constraints:<br> * Pattern: <code> /\\A[0-9]+\\z/ </code><br> * Length: 5</p></p>"
          },
          {
            "group": "Parameter",
            "type": "String",
            "optional": false,
            "field": "partner_city",
            "description": "<p>City of the partner's address. <p>Constraints:<br> * Pattern: <code> /\\A[a-zA-ZäÄöÖüÜß .-]+\\z/ </code> <br> * Max length: 44</p></p>"
          },
          {
            "group": "Parameter",
            "type": "String",
            "optional": false,
            "field": "partner_country",
            "description": "<p>Country of the partner's address. <p>Allowed value: <code>&quot;DEU&quot;</code></p></p>"
          },
          {
            "group": "Parameter",
            "type": "String",
            "optional": false,
            "field": "contract_type",
            "description": "<p>Type of the contract.</p>"
          },
          {
            "group": "Parameter",
            "type": "String",
            "optional": false,
            "field": "contract_number",
            "description": "<p>Number of the contract.</p>"
          },
          {
            "group": "Parameter",
            "type": "String",
            "optional": false,
            "field": "contract_subject",
            "description": "<p>Subject of the contract.</p>"
          },
          {
            "group": "Parameter",
            "type": "Boolean",
            "optional": false,
            "field": "agb_terms",
            "description": "<p>AGB terms.<br> <p>Allowed value: <code>true</code></p></p>"
          },
          {
            "group": "Parameter",
            "type": "Boolean",
            "optional": false,
            "field": "dsv_terms",
            "description": "<p>DSV terms.<br> <p>Allowed value: <code>true</code></p></p>"
          }
        ]
      },
      "examples": [
        {
          "title": "Request: Body example",
          "content": "{\n  \"ident_code\": \"test123\",\n  \"partner_type\": \"LESSOR\",\n  \"partner_iban\": \"DE99123456780123456789\",\n  \"partner_gender\": \"M\",\n  \"partner_firstname\": \"Max\",\n  \"partner_lastname\": \"Mustermann\",\n  \"partner_birthdate\": \"1950-06-01\",\n  \"partner_street\": \"Teststr.\",\n  \"partner_housenumber\": \"10a\",\n  \"partner_postcode\": \"10000\",\n  \"partner_city\": \"Test-Stadt\",\n  \"partner_country\": \"DEU\",\n  \"contract_type\": \"privat\",\n  \"contract_number\": \"051823-X1\",\n  \"contract_subject\": \"Wohnungsmietvertrag\",\n  \"agb_terms\": true,\n  \"dsv_terms\": true\n}",
          "type": "json"
        }
      ]
    },
    "success": {
      "fields": {
        "201 Created": [
          {
            "group": "201 Created",
            "type": "String",
            "optional": false,
            "field": "id",
            "description": "<p>Identifier of the identcheck instance.</p>"
          },
          {
            "group": "201 Created",
            "type": "String",
            "optional": false,
            "field": "process_status",
            "description": "<p>Process status information. <p>Allowed values:</p> <code>SCT_DISCARDED</code><br> <code>SCT_TRIGGERED</code><br> <code>SCT_ACCEPTED</code><br> <code>SCT_FAILED</code><br></p>"
          },
          {
            "group": "201 Created",
            "type": "String",
            "optional": false,
            "field": "process_status_note",
            "description": "<p>Process status note. <p>Allowed values:</p> <code>CHECK_PERSON</code><br> <code>CHECK_BANK_CONNECTION</code><br> <code>SCHUFA_IBAN_VALIDATION_FAILED</code><br> <code>SCHUFA_BIRTHDATE_NOT_VALID_SCOPE</code><br> <code>SCHUFA_DATE_NOT_VALID_SCOPE</code><br> <code>SCHUFA_POSTCODE_NOT_VALID</code><br> <code>SCHUFA_POSTCODE_NOT_ALLOWED</code><br> <code>GATEWAY_SCHEMA_VALIDATION_ERROR</code><br> <code>GATEWAY_IBAN_CHECKSUM_VALIDATION_FAILED</code><br> <code>GATEWAY_IBAN_VALIDATION_FAILED</code><br> <code>INVALID_PROCESS</code><br><br> <p>Value can be <code>null</code>.</p></p>"
          },
          {
            "group": "201 Created",
            "type": "String",
            "optional": false,
            "field": "sct_type",
            "description": "<p>Type of the SCT payment. <p>Allowed values:</p> <code>INSTANT</code><br> <code>STANDARD</code><br><br> <p>Value can be <code>null</code>.</p></p>"
          },
          {
            "group": "201 Created",
            "type": "String",
            "optional": false,
            "field": "created_at",
            "description": "<p>ISO 8601 timestamp of identcheck record creation.</p>"
          },
          {
            "group": "201 Created",
            "type": "...",
            "optional": false,
            "field": "...",
            "description": "<p>Fields having a value of <code>null</code> respective <code>nil</code> are omitted in the response.</p>"
          }
        ]
      },
      "examples": [
        {
          "title": "Response [201]: Example 1",
          "content": "HTTP/1.1 201 Created\n{\n  \"id\": \"f19b621c-39f6-4f0b-873e-ec49cb5021ca\",\n  \"process_status\": \"SCT_TRIGGERED\",\n  \"sct_type\": \"INSTANT\",\n  \"created_at\": \"2020-10-01T10:08:22.384Z\"\n}",
          "type": "json"
        },
        {
          "title": "Response [201]: Example 2",
          "content": "HTTP/1.1 201 Created\n{\n  \"id\": \"c19b621c-39f6-4f0b-873e-ec49cb5021c0\",\n  \"process_status\": \"SCT_DISCARDED\",\n  \"process_status_note\": \"CHECK_BANK_CONNECTION\",\n  \"created_at\": \"2020-10-01T10:07:22.384Z\"\n}",
          "type": "json"
        }
      ]
    },
    "error": {
      "fields": {
        "4xx/5xx Errors": [
          {
            "group": "4xx/5xx Errors",
            "optional": false,
            "field": "400",
            "description": "<p>Bad Request. Diverse reasons. JSON body could be malformated. No response body.</p>"
          },
          {
            "group": "4xx/5xx Errors",
            "optional": false,
            "field": "401",
            "description": "<p>Unauthorized. No response body.</p>"
          },
          {
            "group": "4xx/5xx Errors",
            "optional": false,
            "field": "406",
            "description": "<p>Not Acceptable. Diverse reasons. Application interface requires a proper JSON request. No response body.</p>"
          },
          {
            "group": "4xx/5xx Errors",
            "optional": false,
            "field": "422",
            "description": "<p>Unprocessable Entity. Diverse reasons. Response body see below.</p>"
          },
          {
            "group": "4xx/5xx Errors",
            "optional": false,
            "field": "500",
            "description": "<p>Internal Server Error. No response body.</p>"
          }
        ],
        "422 Unprocessable Entity": [
          {
            "group": "422 Unprocessable Entity",
            "type": "Array[Strings]",
            "optional": false,
            "field": "label",
            "description": "<p>The label is a <code>field name</code> for field-related error(s) or is called <code>base</code> for not field-related error(s).</p>"
          }
        ]
      },
      "examples": [
        {
          "title": "Response [422]: Example",
          "content": "HTTP/1.1 422 Unprocessable Entity\n{\n  \"ident_code\": [\"is too short, minimum is 6 characters\"],\n  \"partner_iban\": [\"is required\", \"pattern matching failed, must match (?-mix:\\\\ADE)\"],\n  \"dsv_terms\": [\"false is not allowed\"]\n}",
          "type": "json"
        }
      ]
    },
    "filename": "app/controllers/identchecks_controller.rb",
    "groupTitle": "IDENTPLUS"
  },
  {
    "type": "GET",
    "url": "/api/v1/identchecks/status/:id.json",
    "title": "Get identcheck status",
    "name": "status_identcheck",
    "group": "IDENTPLUS",
    "version": "1.0.0",
    "header": {
      "fields": {
        "Header": [
          {
            "group": "Header",
            "type": "String",
            "optional": false,
            "field": "Accept",
            "description": "<p>application/json</p>"
          },
          {
            "group": "Header",
            "type": "String",
            "allowedValues": [
              "\"Bearer :token\""
            ],
            "optional": false,
            "field": "Authorization",
            "description": "<p>Replace <code>:token</code> with the supplied Auth Token.</p>"
          }
        ]
      },
      "examples": [
        {
          "title": "Request: Header example",
          "content": "{\n  Accept: \"application/json\",\n  Authorization: \"Bearer XXXXXXXX-XXXX-XXXX-XXXX-XXXXXXXXXXXX\"\n}",
          "type": "json"
        }
      ]
    },
    "description": "<p>Get the status of an identcheck instance identified by URL parameter <code>:id</code>.<br><br></p>",
    "success": {
      "fields": {
        "200 OK": [
          {
            "group": "200 OK",
            "type": "String",
            "optional": false,
            "field": "id",
            "description": "<p>Identifier of the identcheck instance.</p>"
          },
          {
            "group": "200 OK",
            "type": "String",
            "optional": false,
            "field": "process_status",
            "description": "<p>Process status information. <p> Identcheck status requests are not allowed for process_status <code>&quot;SCT_DISCARDED&quot;</code>.<br> Failing this restriction results in rejection.<br> </p> <p>Do stop requesting identcheck status as soon as process_status IS NOT <code>&quot;SCT_TRIGGERED&quot;</code>.</p> <p> To be noted:<br> There is no guarantee that the service provider or financial institutions provide sufficient information in a timely manner, or at all, to be absolutely sure, that the payment has been credited to the payee's account.<br> This needs to be considered when deriving conclusions on process_status values. </p> <p>Allowed values:</p> <code>SCT_TRIGGERED</code><br> <code>SCT_ACCEPTED</code><br> <code>SCT_FAILED</code></p></p>"
          },
          {
            "group": "200 OK",
            "type": "String",
            "optional": false,
            "field": "sct_type",
            "description": "<p>Type of the SCT payment. <p>Allowed values:</p> <code>INSTANT</code><br> <code>STANDARD</code></p>"
          },
          {
            "group": "200 OK",
            "type": "String",
            "optional": false,
            "field": "created_at",
            "description": "<p>ISO 8601 timestamp of identcheck record creation.</p>"
          },
          {
            "group": "200 OK",
            "type": "...",
            "optional": false,
            "field": "...",
            "description": "<p>Fields having a value of <code>null</code> respective <code>nil</code> are omitted in the response.</p>"
          }
        ]
      },
      "examples": [
        {
          "title": "Response [200]: Example 1",
          "content": "HTTP/1.1 200 OK\n{\n  \"id\": \"f19b621c-39f6-4f0b-873e-ec49cb5021ca\",\n  \"process_status\": \"SCT_TRIGGERED\",\n  \"sct_type\": \"INSTANT\",\n  \"created_at\": \"2020-10-01T10:30:29.041Z\"\n}",
          "type": "json"
        },
        {
          "title": "Response [200]: Example 2",
          "content": "HTTP/1.1 200 OK\n{\n  \"id\": \"f19b621c-39f6-4f0b-873e-ec49cb5021ca\",\n  \"process_status\": \"SCT_ACCEPTED\",\n  \"sct_type\": \"INSTANT\",\n  \"created_at\": \"2020-10-01T11:00:29.041Z\"\n}",
          "type": "json"
        }
      ]
    },
    "error": {
      "fields": {
        "4xx/5xx Errors": [
          {
            "group": "4xx/5xx Errors",
            "optional": false,
            "field": "401",
            "description": "<p>Unauthorized. No response body.</p>"
          },
          {
            "group": "4xx/5xx Errors",
            "optional": false,
            "field": "404",
            "description": "<p>Not Found. Response body see below.</p>"
          },
          {
            "group": "4xx/5xx Errors",
            "optional": false,
            "field": "406",
            "description": "<p>Not Acceptable. Diverse reasons. Application interface requires a proper JSON request. No response body.</p>"
          },
          {
            "group": "4xx/5xx Errors",
            "optional": false,
            "field": "422",
            "description": "<p>Unprocessable Entity. Diverse reasons. Response body see below.</p>"
          },
          {
            "group": "4xx/5xx Errors",
            "optional": false,
            "field": "500",
            "description": "<p>Internal Server Error. No response body.</p>"
          }
        ],
        "404 Not Found, 422 Unprocessable Entity": [
          {
            "group": "404 Not Found, 422 Unprocessable Entity",
            "type": "Array[Strings]",
            "optional": false,
            "field": "label",
            "description": "<p>The label is a <code>field name</code> for field-related error(s) or is called <code>base</code> for not field-related error(s).</p>"
          }
        ]
      },
      "examples": [
        {
          "title": "Response [404]: Example 1",
          "content": "HTTP/1.1 404 Not Found\n{\n  \"base\": [\"record not found\"]\n}",
          "type": "json"
        },
        {
          "title": "Response [422]: Example 1",
          "content": "HTTP/1.1 422 Unprocessable Entity\n{\n  \"base\": [\"process status not acceptable\"]\n}",
          "type": "json"
        },
        {
          "title": "Response [422]: Example 2",
          "content": "HTTP/1.1 422 Unprocessable Entity\n{\n  \"base\": [\"record age exceeded\"]\n}",
          "type": "json"
        }
      ]
    },
    "filename": "app/controllers/identchecks_controller.rb",
    "groupTitle": "IDENTPLUS"
  }
] });
